@@ -31,6 +31,7 @@ from calibre.gui2.complete2 import EditWithComplete
 ROOT = QModelIndex()
 PARAGRAPH_SEPARATOR = '\u2029'
 
+
 class BusyCursor(object):
 
     def __enter__(self):
@@ -39,11 +40,13 @@ class BusyCursor(object):
     def __exit__(self, *args):
         QApplication.restoreOverrideCursor()
 
+
 class Dialog(BaseDialog):
 
     def __init__(self, title, name, parent=None):
         BaseDialog.__init__(self, title, name, parent=parent, prefs=tprefs)
 
+
 class InsertTag(Dialog):  # {{{
 
     def __init__(self, parent=None):
@@ -77,6 +80,7 @@ class InsertTag(Dialog):  # {{{
 
 # }}}
 
+
 class RationalizeFolders(Dialog):  # {{{
 
     TYPE_MAP = (
@@ -118,7 +122,7 @@ class RationalizeFolders(Dialog):  # {{{
             l.addWidget(le, i + 1, 1)
         self.la2 = la = QLabel(_(
             'Note that this will only arrange files inside the book,'
-            ' it will not affect how they are displayed in the Files Browser'))
+            ' it will not affect how they are displayed in the File Browser'))
         la.setWordWrap(True)
         l.addWidget(la, i + 2, 0, 1, -1)
         l.addWidget(self.bb, i + 3, 0, 1, -1)
@@ -136,6 +140,7 @@ class RationalizeFolders(Dialog):  # {{{
         return Dialog.accept(self)
 # }}}
 
+
 class MultiSplit(Dialog):  # {{{
 
     def __init__(self, parent=None):
@@ -170,6 +175,7 @@ class MultiSplit(Dialog):  # {{{
 
 # }}}
 
+
 class ImportForeign(Dialog):  # {{{
 
     def __init__(self, parent=None):
@@ -252,6 +258,7 @@ class ImportForeign(Dialog):  # {{{
 
 # Quick Open {{{
 
+
 def make_highlighted_text(emph, text, positions):
     positions = sorted(set(positions) - {-1})
     if positions:
@@ -266,6 +273,7 @@ def make_highlighted_text(emph, text, positions):
         return ''.join(parts)
     return text
 
+
 class Results(QWidget):
 
     EMPH = "color:magenta; font-weight:bold"
@@ -396,6 +404,7 @@ class Results(QWidget):
         except IndexError:
             pass
 
+
 class QuickOpen(Dialog):
 
     def __init__(self, items, parent=None):
@@ -470,6 +479,7 @@ class QuickOpen(Dialog):
 
 # Filterable names list {{{
 
+
 class NamesDelegate(QStyledItemDelegate):
 
     def sizeHint(self, option, index):
@@ -509,6 +519,7 @@ class NamesDelegate(QStyledItemDelegate):
             doc.drawContents(painter)
         painter.restore()
 
+
 class NamesModel(QAbstractListModel):
 
     filtered = pyqtSignal(object)
@@ -553,6 +564,7 @@ class NamesModel(QAbstractListModel):
         except IndexError:
             pass
 
+
 def create_filterable_names_list(names, filter_text=None, parent=None, model=NamesModel):
     nl = QListView(parent)
     nl.m = m = model(names, parent=nl)
@@ -570,6 +582,7 @@ def create_filterable_names_list(names, filter_text=None, parent=None, model=Nam
 
 # Insert Link {{{
 
+
 class AnchorsModel(QAbstractListModel):
 
     filtered = pyqtSignal(object)
@@ -602,6 +615,7 @@ class AnchorsModel(QAbstractListModel):
         self.endResetModel()
         self.filtered.emit(not bool(query))
 
+
 class InsertLink(Dialog):
 
     def __init__(self, container, source_name, initial_text=None, parent=None):
@@ -643,6 +657,7 @@ class InsertLink(Dialog):
         h.addLayout(fnl), h.setStretch(1, 1)
 
         self.tl = tl = QFormLayout()
+        tl.setFieldGrowthPolicy(tl.AllNonFixedFieldsGrow)
         self.target = t = QLineEdit(self)
         t.setPlaceholderText(_('The destination (href) for the link'))
         tl.addRow(_('&Target:'), t)
@@ -718,6 +733,7 @@ class InsertLink(Dialog):
 
 # Insert Semantics {{{
 
+
 class InsertSemantics(Dialog):
 
     def __init__(self, container, parent=None):
@@ -910,6 +926,7 @@ class InsertSemantics(Dialog):
 
 # }}}
 
+
 class FilterCSS(Dialog):  # {{{
 
     def __init__(self, current_name=None, parent=None):
@@ -981,6 +998,7 @@ class FilterCSS(Dialog):  # {{{
 
 # Add Cover {{{
 
+
 class CoverView(QWidget):
 
     def __init__(self, parent=None):
@@ -1018,6 +1036,7 @@ class CoverView(QWidget):
     def sizeHint(self):
         return QSize(300, 400)
 
+
 class AddCover(Dialog):
 
     import_requested = pyqtSignal(object, object)
@@ -1116,6 +1135,7 @@ class AddCover(Dialog):
 
 # }}}
 
+
 class PlainTextEdit(QPlainTextEdit):  # {{{
 
     ''' A class that overrides some methods from QPlainTextEdit to fix handling
@@ -1176,6 +1196,7 @@ class PlainTextEdit(QPlainTextEdit):  # {{{
 
 # }}}
 
+
 if __name__ == '__main__':
     app = QApplication([])
     AddCover.test()
